﻿/*
 * This file is part of ursa, a tokencode generator compatible with 
 * RSA SecurID® 128-bit (AES) tokens. RSA SecurID® is a registered 
 * trademark held by RSA Security LLC.  Neither the ursa project 
 * nor Samoyed Software, LLC are affiliated with or endorsed by 
 * RSA® (RSA Security LLC). 
 * 
 * Copyright 2017 Samoyed Software, LLC <http://www.samoyedsoftware.com>
 *
 * Portions of ursa are based on 
 * stoken 0.92, Copyright 2012 Kevin Cernekee <http://stoken.sf.net/>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ursa.Extensions
{
    /// <summary>
    /// Framework extensions to the type <see cref="DateTime"/>.
    /// </summary>
    internal static class DateTimeExtension
    {
        public static byte[] ToBCDFormat(this DateTime dt)
        {
            return dt.ToPackedBCD(-1);
        }

        public static byte[] ToPackedBCD(this DateTime dt, int byteCount)
        {
            if (byteCount < 0)
                byteCount = 6;
            else if (byteCount < 6)
                throw new ArgumentOutOfRangeException("byteCount", "Byte count must be at least 6.");
            
            byte[] bcd = new byte[byteCount];
            byte[] buf;

            buf = dt.Year.ToPackedBCD();
            buf.CopyTo(0, bcd, 0, Math.Min(buf.Length, 2));

            buf = dt.Month.ToPackedBCD();
            bcd[2] = buf[0];

            buf = dt.Day.ToPackedBCD();
            bcd[3] = buf[0];

            buf = dt.Hour.ToPackedBCD();
            bcd[4] = buf[0];

            buf = dt.Minute.ToPackedBCD();
            bcd[5] = buf[0];

            for (int i = 6; i < byteCount; i++)
                bcd[i] = 0;

            return bcd;
        }

    }
}
