﻿/*
 * This file is part of ursa, a tokencode generator compatible with 
 * RSA SecurID® 128-bit (AES) tokens. RSA SecurID® is a registered 
 * trademark held by RSA Security LLC.  Neither the ursa project 
 * nor Samoyed Software, LLC are affiliated with or endorsed by 
 * RSA® (RSA Security LLC). 
 * 
 * Copyright 2017 Samoyed Software, LLC <http://www.samoyedsoftware.com>
 *
 * Portions of ursa are based on 
 * stoken 0.92, Copyright 2012 Kevin Cernekee <http://stoken.sf.net/>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ursa.Extensions
{
    /// <summary>
    /// Framework extensions to the type <see cref="String"/>.
    /// </summary>
    internal static class StringExtension
    {
        public static byte[] DecodeCharsIntoBits(this string str, int offset, uint totalBits, uint bitsPerChar)
        {
            byte[] result = new byte[(totalBits + 7) / 8];
            result.SetAll(0);

            uint iBitCount = 0;
            uint iByteCount = 0;
            int bitShift = sizeof(ushort) * 8 - (int) bitsPerChar;
            uint bitMask = ((uint) 1 << (int) bitsPerChar) - 1;

            for (int srcIdx = offset; srcIdx < str.Length && iBitCount < totalBits; srcIdx++, iBitCount += bitsPerChar)
            {
                ushort decoded = (ushort) ((str[srcIdx] - '0') & bitMask);
                decoded <<= bitShift;

                result[iByteCount] |= (byte) (decoded >> 8);
                result[iByteCount + 1] |= (byte) (decoded & 0xff);

                bitShift -= (int) bitsPerChar;
                if (bitShift < 0)
                {
                    bitShift += 8;
                    iByteCount++;
                }
            }

            return result;
        }

    }
}
