﻿/*
 * This file is part of ursa, a tokencode generator compatible with 
 * RSA SecurID® 128-bit (AES) tokens. RSA SecurID® is a registered 
 * trademark held by RSA Security LLC.  Neither the ursa project 
 * nor Samoyed Software, LLC are affiliated with or endorsed by 
 * RSA® (RSA Security LLC). 
 * 
 * Copyright 2017 Samoyed Software, LLC <http://www.samoyedsoftware.com>
 *
 * Portions of ursa are based on 
 * stoken 0.92, Copyright 2012 Kevin Cernekee <http://stoken.sf.net/>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ursa.Extensions
{
    /// <summary>
    /// Framework extensions to the type <see cref="UInt32"/>.
    /// </summary>
    internal static class UInt32Extension
    {
        public static byte[] ToPackedBCD(this int val)
        {
            if (val < 0)
                throw new ArgumentException("Negative values are not permitted.", "val");

            int byteCount = (val == 0) ? 1 : (int)Math.Ceiling(Math.Floor(Math.Log10(val) + 1) / 2);
            byte[] bcd = new byte[byteCount];

            for (int i = byteCount - 1; i >= 0; i--)
            {
                bcd[i] = (byte) (val % 10);
                val /= 10;
                bcd[i] |= (byte) (((uint) val % 10) << 4);
                val /= 10;
            }

            return bcd;
        }

    }
}
