﻿/*
 * This file is part of ursa, a tokencode generator compatible with 
 * RSA SecurID® 128-bit (AES) tokens. RSA SecurID® is a registered 
 * trademark held by RSA Security LLC.  Neither the ursa project 
 * nor Samoyed Software, LLC are affiliated with or endorsed by 
 * RSA® (RSA Security LLC). 
 * 
 * Copyright 2017 Samoyed Software, LLC <http://www.samoyedsoftware.com>
 *
 * Portions of ursa are based on 
 * stoken 0.92, Copyright 2012 Kevin Cernekee <http://stoken.sf.net/>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ursa
{
    /// <summary>
    /// Specifies the type of error represented by an <see cref="ursaException"/> object.
    /// </summary>
    public enum ursaError
    {
        /// <summary>
        /// Success
        /// </summary>
        None,
        /// <summary>
        /// General error
        /// </summary>
        GeneralError,
        /// <summary>
        /// XML is invalid
        /// </summary>
        XmlInvalid,
        /// <summary>
        /// Token string is invalid
        /// </summary>
        TokenStringInvalid,
        /// <summary>
        /// Token version is invalid
        /// </summary>
        TokenVersionInvalid,
        /// <summary>
        /// Checksum validation failed
        /// </summary>
        ChecksumFailed,
        /// <summary>
        /// Password is required
        /// </summary>
        PasswordRequired,
        /// <summary>
        /// PIN is required
        /// </summary>
        PinRequired,
        /// <summary>
        /// Token must be decrypted by calling the <see cref="SecurIdToken.Decrypt(string, string)"/>Decrypt method before the requested action can be completed
        /// </summary>
        TokenNeedsDecrypted,
        /// <summary>
        /// Decryption failed
        /// </summary>
        DecryptionFailed,
        /// <summary>
        /// Device ID is not valid
        /// </summary>
        DeviceIdInvalid,
        /// <summary>
        /// Device ID is required
        /// </summary>
        DeviceIdRequired,
        /// <summary>
        /// File could not be read
        /// </summary>
        FileReadFailed,
        /// <summary>
        /// SDTID token has multiple TKN elements
        /// </summary>
        SdtidMultipleTokens
    }
}
